﻿using System;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Windows.Forms;

using MindFusion.Mapping;
using MindFusion.Mapping.WinForms;


namespace Database
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void MainForm_Load(object sender, EventArgs e)
		{
			mapView.BaseMap = new Map();

			// load data from the dbf database associated with shapefile
			// and set values from the NAME column as labels
			mapView.BaseMap.LoadFromFile(
				FindMap("ne_50m_admin_0_countries.shp"), true, "NAME");

			// select fill colors so that adjacent countries are painted in different color
			mapView.BaseMap.AssignColors();

			// do not display border lines
			mapView.Layers[0].LineColor = Color.Empty;

			// necessary in order to receive mouse wheel events
			mapView.Focus();
		}

		private void OnMapElementClick(object sender, MapEventArgs e)
		{
			var shape = e.MapElement as Shape;
			if (shape == null)
				return;
			
			propertyGrid.SelectedObject = shape.DatabaseRow;

			if (e.Button == MouseButtons.Right)
				Process.Start("http://en.wikipedia.org/wiki/" + shape.Label.Text);
		}

		private void miFileLoadMap_Click(object sender, EventArgs e)
		{
			var openDialog = new OpenFileDialog
			{
				Filter = "Shapefile map|*.shp",
				Title = "Open map"
			};

			if (openDialog.ShowDialog() == DialogResult.OK)
			{
				mapView.BaseMap = new Map();
				mapView.BaseMap.LoadFromFile(openDialog.FileName, true);
				mapView.Invalidate();
			}
		}

		private void miFileExit_Click(object sender, EventArgs e)
		{
			Close();
		}

		private string FindFolder(string folderName)
		{
			string testDir = @"..\Maps\";
			for (int i = 0; i < 10; i++)
			{
				if (Directory.Exists(testDir))
					break;
				testDir = @"..\" + testDir;
			}

			var testFolder = testDir + folderName;
			if (Directory.Exists(testFolder))
				return testFolder;

			return "";
		}

		private string FindMap(string fileName)
		{
			var testFolders = new[]
			{
				FindFolder(@"50m_cultural\"),
				FindFolder(@"50m_physical\")
			};

			foreach (string folder in testFolders)
			{
				var testFile = folder + fileName;
				if (File.Exists(testFile))
					return testFile;
			}

			return null;
		}
	}
}